function [solution,iter] = Newton(c0,K1,K2,rho,x0,tol)
// Solves the non-linear vector equation f(x)=0 set using Newton Raphson iteration
//(but with a the ability to reduce the length of the step until the a decrease in error is detected)
// INPUTS:
// rho    = Relaxation factor
// x0	 = Initial Guess (a vector)
// tol	 = Tolerance
// 
// OUTPUTS
// solution = The solution to f(x) = 0
// iter     = Iterations
x = x0;
itemax = 100;
// set the error 2*tol to make sure the loop runs at least once
error = 2*tol;
iter = 1;
while error > tol
      //calculate the function values at the current iteration
      f = Ex_04_func(x,c0,K1,K2);  
      //calculate the error
      error1 = max(abs(f));  
      //calculate the jacobian matrix
      J = Jacobian(x,c0);  
      //calculate the update (solve the linear system)
      dx = J\(-f);
      //calculate the error
      xnew = x + dx;
      f = Ex_04_func(xnew,c0,K1,K2);
      error2 = max(abs(f)); 
      //update the x value
      i=1;
      imax=10;
      while (error2>=error1||~isreal(f))
          xnew = x+(rho^i)*dx;
          f = Ex_04_func(xnew,c0,K1,K2);
          error2 = max(abs(f));
          i = i+1;
          if i > imax
            disp(' No convergence: Change relaxation factor or initial guesses')
            solution = xnew;
            resume
          end
      end
      x = xnew;
      //calculate the error
      f = Ex_04_func(x,c0,K1,K2);
      error = max(abs(f))
      iter = iter + 1;
      if iter > itemax
        disp(' No convergence: Change initial guesses or maximum number of iterations ')
        solution = x;
        resume
      end
end //while loop
solution = x;
endfunction
